@@ -1,8 +1,11 @@
-import sys
+import json
 from typing import Any
+from urllib.error import URLError
 
 import luddite
 import pkg_resources
+import sys
+from cli_ui import debug as verbose
 from cli_ui import (
     message,
     info,
@@ -18,10 +21,7 @@ from cli_ui import (
     Symbol,
     Token,
 )
-from cli_ui import debug as verbose
-
 from packaging import version as packaging_version
-from urllib.error import URLError
 
 from gitlabform import EXIT_PROCESSING_ERROR, EXIT_INVALID_INPUT, Entities
 
@@ -218,3 +218,9 @@ def info_count(color, prefix, i: int, n: int, *rest: Token, **kwargs: Any) -> No
     counter_format = "(%{}d/%d)".format(num_digits)
     counter_str = counter_format % (i, n)
     info(color, prefix, reset, counter_str, reset, *rest, **kwargs)
+
+
+def to_str(a_dict: dict) -> str:
+    # arguably the most readable form of a dict in a single line
+    # is JSON with sorted keys
+    return json.dumps(a_dict, sort_keys=True)
